@@ -408,7 +408,7 @@ class ReportDownloader(object):
       while True:
         chunk = response.read(_CHUNK_SIZE)
         if not chunk: break
-        output.write(chunk.decode())
+        output.write(chunk.decode() if sys.version_info[0] == 3 else chunk)
 
   def _SerializeAwql(self, query, file_format):
     """Serializes an AWQL query and file format for transport.
